* ---------------------------------------------------------------- colmerge
      Program ColMerge

* Merges entries in a series of column files into a single column file.

* This version assumes that nx is the same for all files
* See smc2asc to see how to deal with unequal nx values

* The next line is the first line in a sample control file:
*!Control file for program ColMerge
*! Revision of program involving a change in the control file on this date:
* 10/07/13
*!Output file name:
* colmerge.col
*!Use first or last part of file name for column header (F, L)?
* F
*!N lines to skip to get to data
* 1
*!N columns to read, columns for x and y columns 
*!  (for files made using blpadflt, period is in column 1 and sd, pv, pa, rv, 
*!  aa are in columns 2, 3, 4, 5, 6, respectively)
* 6 1 3
*!Output a single x column? (y,n: if yes, use x column from first file):
* y
*!Compute ratios?
* y
*!If compute ratios, which file provides the denominator (a placeholder is needed in any case):
* 2
*!file ("STOP" in any column, any case, to quit)
*1397c_u.smc.rm_v0_alc_p02.r.col
*1731a_u.smc.rm_v0_alc_p02.r.col
*1734a_u.smc.rm_v0_alc_p02.r.col
*stop

* Dates: 02/17/04 - Written by D. Boore, based on band_avg
*        12/05/07 - Write file names as headers before the columns
*        10/09/08 - Add an option to output a single x column
!        03/31/10 - Updated coding, using some F95 constructs.
!                 - Increased array dimensions.
!        05/11/10 - Allow nx to be different for each file (see
!                   smc2asc).
!        04/22/11 - Allow for more files
!        02/04/12 - Allow for longer file names and more files
!        08/07/12 - Write "." as a placeholder in output if there are no model
!                   values for a depth
!        07/04/13 - Use Fortran 95 extension getcl to get a command line argument that determines if
!                   the default control file name is used (this will be used for calling the main
!                   program within a batch file (c:\forprogs\colmerge -default_ctl)
!        08/06/13 - Increase x and y array dimension
!        10/07/13 - Add an option to compute ratios of columns
!        05/19/20 - Catch bug, when specify one x column, but the y files have different lengths
 
      parameter(nfiles_max = 100)

      character comments(200)*80, buf*200, bufuc*4, output_1_x_column*5
      real x(200000,nfiles_max), y(200000,nfiles_max), dum(30)
      character f_in(nfiles_max)*200, f_out*200
      character header(nfiles_max)*12, compute_ratios*10

      character colhead(400)*14
      
      character x_c(nfiles_max)*14
      character y_c(nfiles_max)*14
      character rat_c(nfiles_max)*14

      character frmt_colhead*10, frmt_e*16,
     :          frmt_line*8, cl_arg*50

      integer nper, nc_f_in(nfiles_max)
      
      integer npx(nfiles_max)
      
      integer nfile4denom

      character date_ctl_correct*8, date_ctl_in*30

      character f_ctl*100
      logical f_exist, use_first, file_exist

      twopi = 2.0*4.0*atan(1.0)

      f_exist = .false.
      cl_arg = ' '
      call getcl(cl_arg)
      call trim_c(cl_arg, nc_cl_arg)
      if (nc_cl_arg > 0) then
        f_ctl = ' '
        f_ctl = 'colmerge.ctl'
        call trim_c(f_ctl, nc_f_ctl)
        inquire(file=f_ctl(1:nc_f_ctl), exist=f_exist)
          if (.not. f_exist) then
            write(*,'(a)') 
     :             ' ******* CONTROL FILE '//f_ctl(1:nc_f_ctl)//
     :             ' DOES NOT EXIST; QUITTING! ******* '
            stop
          end if
      else 
        do while (.not. f_exist)
          f_ctl = ' '
          write(*, '(a\)') 
     :      ' Enter name of control file '//
     :      '(Enter=colmerge.ctl;'//
     :      ' ctl-brk to quit): '
          read(*, '(a)') f_ctl
          if (f_ctl(1:4) .eq. '    ') 
     :      f_ctl = 'colmerge.ctl'
          call trim_c(f_ctl, nc_f_ctl)
          inquire(file=f_ctl(1:nc_f_ctl), exist=f_exist)
          if (.not. f_exist) then
            write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
          end if
        end do
      end if

      call get_lun(nu_ctl)
      open(unit=nu_ctl,file=f_ctl(1:nc_f_ctl),status='unknown')
      write(*,'(a)') ' f_ctl = '//f_ctl(1:nc_f_ctl)

      call skipcmnt(nu_ctl,comments,nc_cmnts)
      date_ctl_in = ' '
      read(nu_ctl,'(a)') date_ctl_in
      call trim_c(date_ctl_in,nc_date_ctl_in)
      
      date_ctl_correct = ' '
      date_ctl_correct = '10/07/13'
      call trim_c(date_ctl_correct,nc_date_ctl_correct)

      if (date_ctl_correct(1:nc_date_ctl_correct) .ne. 
     :    date_ctl_in(1:nc_date_ctl_in)) then
        write(*,'(a)') 
     :     ' The control file has the wrong date; update your '//
     :       'control file and rerun the program!'
        close(nu_ctl)
        stop
      end if
      
      call skipcmnt(nu_ctl,comments,nc_cmnts)
      f_out = ' '
      read(nu_ctl,'(a)') f_out
      call trim_c(f_out, nc_f_out)
      write(*,'(a)') ' f_out = '//f_out(1:nc_f_out)

* Read variable specifying what part of file name is used in column header:
      call skipcmnt(nu_ctl,comments,nc_cmnts)
      buf = ' '
      read(nu_ctl, '(a)') buf
      call trim_c(buf,nc_buf)
      bufuc = ' '
      bufuc = buf(1:1)
      call upstr(bufuc)
      if (bufuc(1:1) .eq. 'F') then
        use_first = .true.
      else
        use_first = .false.
      end if
      write(*, '(a,1x,l)') ' use_first = ', use_first

      call skipcmnt(nu_ctl,comments,nc_cmnts)
      read(nu_ctl,*) n_lines_to_skip
      write(*,'(a,1x, i3)') ' n_lines_to_skip = ', n_lines_to_skip

      call skipcmnt(nu_ctl,comments,nc_cmnts)
      read(nu_ctl,*) ncol2read, icolx, icoly
      write(*,'(a,3(1x,i3))') 
     :  ' ncol2read, icolx, icoly = ', ncol2read, icolx, icoly

      call skipcmnt(nu_ctl,comments,nc_cmnts)
      output_1_x_column = ' '     
      read(nu_ctl,'(a)') output_1_x_column
      call trim_c(output_1_x_column, nc_output_1_x_column)
      call upstr(output_1_x_column)

      call skipcmnt(nu_ctl,comments,nc_cmnts)
      compute_ratios = ' '     
      read(nu_ctl,'(a)') compute_ratios
      call trim_c(compute_ratios, nc_compute_ratios)
      call upstr(compute_ratios)
      
      call skipcmnt(nu_ctl,comments,nc_cmnts)
      read(nu_ctl,*) nfile4denom
      if (compute_ratios(1:1) == 'Y') then
        write(*,'(a,3(1x,i3))') 
     :  ' nfile4denom = ', nfile4denom
      end if
 
      call skipcmnt(nu_ctl,comments,nc_cmnts)

      ifile = 0

      loop over files: DO

 
        buf = ' '
        read(nu_ctl,'(a)') buf
        call trim_c(buf,nc_buf)
 
        bufuc = ' '
        bufuc = buf(1:4)
        call upstr(bufuc)
        if(bufuc(1:4) == 'STOP') then
           EXIT loop over files
        end if
 
        ifile = ifile + 1
  
        f_in(ifile) = ' '
        f_in(ifile) = buf(1:nc_buf)
        call trim_c(f_in(ifile), nc_f_in(ifile))
        file_exist = .false.
        inquire(file=f_in(ifile)(1:nc_f_in(ifile)), exist=file_exist)
        if (.not. file_exist) then
          write(*,'(a)') ' ******* FILE '//
     :                    f_in(ifile)(1:nc_f_in(ifile))//
     :                ' DOES NOT EXIST; QUITTING! ******* '
          close (nu_ctl)
          STOP
        end if
        call get_lun(nu_in)
        open(unit=nu_in,file=f_in(ifile)(1:nc_f_in(ifile)),
     :     status='unknown')
        write(*,'(a)') '   f_in = '//f_in(ifile)(1:nc_f_in(ifile))

* Read the input file:

        nx = 0

        call skip(nu_in,n_lines_to_skip)  !   skip to data

        DO

          read(nu_in,*, iostat=iread_status) (dum(i), i=1, ncol2read)
          if(iread_status /= 0) then
            close(nu_in)
            EXIT
          end if

          nx = nx + 1    

          x(nx, ifile) = dum(icolx)
          y(nx, ifile) = dum(icoly)

        END DO
        
        npx(ifile) = nx

        write(*,'(a)') ' finished reading file '//
     :                 f_in(ifile)(1:nc_f_in(ifile))
        write(*,*)

* Construct column heads, see smc2asc or smc2rs or fas_avg

        colhead(2*ifile-1)(1:14) = ' ............x'

        colhead(2*ifile)(1:14) =   ' .............'
        if (use_first) then
          n1 = max0(2, 14-nc_f_in(ifile)+1)
          nf2 = min0(14, nc_f_in(ifile))
          colhead(2*ifile)(n1:14) = f_in(ifile)(1:nf2)
        else
          n1 = max0(2, 14-nc_f_in(ifile)+1)
          nf1 = max0(2, nc_f_in(ifile) - 14 + 1)
          colhead(2*ifile)(n1:14) = f_in(ifile)(nf1:nc_f_in(ifile))
        end if

      END DO loop over files ! go back for another file
      
      nfiles = ifile
      write(*,'(a,1x,i3)') ' nfiles = ', nfiles

! write output

      call get_lun(nu_out)
      open(unit=nu_out,file=f_out(1:nc_f_out),status='unknown')

      write(nu_out,'(a,1x,i3)') ' nfiles = ', nfiles
      do i = 1, nfiles
        write(nu_out,'(a)') f_in(i)(1:nc_f_in(i))
      end do

      if (compute_ratios(1:1) == 'Y') then
        write(*,'(a,1x,i3,a)') 
     :    ' Ratios computed, with file ', nfile4denom, 
     :    ' as the denominator'
        write(nu_out,'(a,1x,i3,a)') 
     :    ' Ratios computed, with file ', nfile4denom, 
     :    ' as the denominator'
        DO j = 1, nfiles
          colhead(2*nfiles+j)(1:14) =   ' rat_...div...'
          write(colhead(2*nfiles+j)(6:8),'(i3.3)') j
          write(colhead(2*nfiles+j)(12:14),'(i3.3)') nfile4denom
        END DO
      end if
      frmt_colhead = ' '
      frmt_colhead = '(xxx(a14))'

      frmt_e = ' '
      frmt_e = '(xxx(2x,es12.5))'
      write(frmt_e(2:4),'(i3)') 2*nfiles

      frmt_line = ' '
      frmt_line = '(xxx(a))'
      write(frmt_line(2:4), '(i3)') 2*nfiles

* Find nxmax:
      call imnmax(npx,1,nfiles,1,nxmin,nxmax) 

      if (output_1_x_column(1:1) == 'Y' .and. nxmin /= nxmax) then
        write(*,*)
        write(*,'(a)') 
     :     ' Asked for one x column, but nxmin .ne. nxmax'
        write(*,'(a,2(1x,i6))') ' nxmin, nxmax = ', nxmin, nxmax
        write(*,'(a)') ' npx'
        do i = 1, nfiles
          write(*,'(1x,i6)') npx(i)
        end do
        write(*, '(a)') ' QUITTING!!!'
        stop
      end if
       
      x_c = ' '
      y_c = ' '
      
      if (compute_ratios(1:1) /= 'Y') then
      
        if (output_1_x_column(1:1) .eq. 'Y') then
          write(frmt_colhead(2:4),'(i3)')  nfiles + 1
          write(nu_out, frmt_colhead) colhead(1), colhead(2), 
     :                       (colhead(2*j), j = 2, nfiles)
          do i = 1, nxmax
            write(nu_out,frmt_e) x(i,1), y(i,1), 
     :                        (y(i,j), j = 2, nfiles)
          end do 
        else
          write(frmt_colhead(2:4),'(i3)') 2*nfiles
          write(nu_out, frmt_colhead) (colhead(j), j = 1, 2*nfiles)
          do i = 1, nxmax
            x_c = ' '
            y_c = ' '
            do j = 1, nfiles
              if (i .le. npx(j)) then              ! fill output string with value
                write(x_c(j), '(2x,es12.5)') x(i,j)
                write(y_c(j), '(2x,es12.5)') y(i,j)
              else
!                      'xx123456789012'
                x_c(j) = '             .'
                y_c(j) = '             .'
              end if
            end do
            write(nu_out,frmt_line) (x_c(j),y_c(j), j=1,nfiles)
          end do
        end if

      else
      
        if (output_1_x_column(1:1) .eq. 'Y') then
          
          write(frmt_colhead(2:4),'(i3)')  nfiles + 1 + nfiles
          write(nu_out, frmt_colhead) colhead(1), colhead(2), 
     :                       (colhead(2*j), j = 2, nfiles),
     :                       (colhead(2*nfiles+j), j = 1, nfiles)

          frmt_e = ' '
          frmt_e = '(xxx(2x,es12.5))'
          write(frmt_e(2:4),'(i3)') 2*nfiles + nfiles


          do i = 1, nxmax
            write(nu_out,frmt_e) x(i,1), y(i,1), 
     :                        (y(i,j), j = 2, nfiles),
     :                        (y(i,j)/y(i,nfile4denom), j=1, nfiles)
          end do 
          
        else

          write(frmt_colhead(2:4),'(i3)') 2*nfiles + nfiles
          write(nu_out, frmt_colhead) (colhead(j), j = 1, 2*nfiles),
     :                       (colhead(2*nfiles+j), j = 1, nfiles)


          frmt_line = ' '
          frmt_line = '(xxx(a))'
          write(frmt_line(2:4), '(i3)') 2*nfiles + nfiles

          do i = 1, nxmax
            x_c = ' '
            y_c = ' '
            rat_c = ' '
            do j = 1, nfiles
              if (i .le. npx(j)) then              ! fill output string with value
                write(x_c(j), '(2x,es12.5)') x(i,j)
                write(y_c(j), '(2x,es12.5)') y(i,j)
                write(rat_c(j), '(2x,es12.5)') y(i,j)/y(i,nfile4denom)
              else
!                      'xx123456789012'
                x_c(j) = '             .'
                y_c(j) = '             .'
                rat_c(j) = '             .'
              end if
            end do
            write(nu_out,frmt_line) (x_c(j),y_c(j), j=1,nfiles), 
     :                                   (rat_c(j), j=1,nfiles)
     
          end do
          
        end if

      end if 
      
      close(nu_out)
      stop

      end
* ---------------------------------------------------------------- colmerge

  
  
      include '\forprogs\imnmax.for'
      include '\forprogs\upstr.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\skip.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\skipcmnt.for'
      include '\forprogs\avevar.for'
      include '\forprogs\locate.for'

