! ------------------ BEGIN SMC2ASC -----------------------------
      Program SMC2ASC

! Read a control file with info for 1 to 72 smc files.  Read
! the smc file and reformat to produce a column file (actually, in
! CoPlot parlance, a wrapped ascii file).

! This version can read time series, response spectra, or Fourier spectra

! Here as a sample input file:

!!Control file for SMC2ASC      ! first line
!!Name of output file:
! smc2asc.asc
!!Want blank or 1e37 for blanks (1=blank)
! 1
!!Use first or last part of file name for column header (F, L)?
! F
!! Processing parameters ndecim, skip, tlength, xfactr, tshift (+ to right)
!! followed by the list for which these parameters will be used.  The column
!! labels will be made up of the file name (and no path)
!! with "V" or "H" appended on the right to indicate component.  The line
!! with the processing parameters must have the string "pp:" somewhere before
!! the parameters
!pp: 1  0.0 999.0 +1 0.0 ! ndecim, tskip, tlength, xfactr, tshift (+ to right)
! \psv\taiwan99\t0781pea.smc
! file2.smc
!pp:2 30.0 999.0 -1 12.0 ! ndecim, tskip, tlength, xfactr, tshift (+ to right)
! \psv\taiwan99\t1293l3v.smc
!pp:4 0.0 999.0 -1 -25.0 ! ndecim, tskip, tlength, xfactr, tshift (+ to right)
! \psv\taiwan99\t0781ped.smc
!pp: 1 0.05 0.0  0 0.0 ! type of rs(0=RD,1=PSV,2=PSA,3=RV,4=AA), damping, placeholders(r,i,r)
!1099c_r.rs2
!1405b_r.rs2
!1417b_r.rs2
!pp: 0 0.0 0.0 0 0.0 ! for Fourier spectra, use placeholders (i,r,r,i,r)
!1099c_r.fs2
!1405b_r.fs2
!1417b_r.fs2
!stop

! Dates: 07/17/97 - Written by D. Boore
!        08/16/97 - Allow for a 6 character id tag
!                   increase # of time points to 11,000
!        08/20/97 - Named changed to SMC2ASC to be more exact (it creates
!                   a *.ASC file)
!        10/20/97 - Increased number of time points to 16,000
!        12/16/97 - Added a sample input file
!        12/23/97 - Allowed for comment lines in input file
!        03/09/98 - Increased number of time points to 25,000
!        03/30/98 - Increased number of time points to 30,000
!                   and compile using Lahey Fortran
!        03/09/99 - Use get_lun to obtain logical unit number
!                   and use an updated version of SMCRead
!        09/16/99 - Replaced SMCRead with newest version (and had to change
!                   the statement calling this routine)
!        10/16/99 - Increased dimension to 100000, number of time series to
!                   10, removed requirement that idtag start in a given
!                   column (but still restrict it to 6 characters after
!                   stripping off the leading and trailing blanks), allow
!                   the tag to be 8 characters, include tskip,
!                   and added possibility to decimate the output
!        12/02/99 - Inquire as to existence of time series file
!        12/16/99 - Added lines at beginning giving number of variables, etc.
!                   for ease in importing into CoPlot
!        02/10/00 - Added sign variable
!        02/12/00 - Include tshift for each trace
!        12/06/00 - Delete specification of number of files in control file 
!                   substitute "Stop" (any column, upper or lowercase).
!        12/08/00 - Use dynamically allocatable arrays
!        12/11/00 - Increased dimension of comments to 500 (I ran into
!                   a difficult-to-debug problem when the dimension was set at
!                   50, but the number of comments was greater than 50.  The
!                   error message claimed an invalid unit number in smcread
!        12/14/00 - Use RCC to read in idtag
!        01/14/01 - Brought comments in sample control file up to date;
!                   recompiled, although did not need to do so.
!        01/16/01 - Correct problem with computing max number of time points 
!                   in output
!        01/20/01 - Add ndecim, tskip, tlength, isign_ts, tshift to output
!        04/30/01 - Option for blank or 1e37 for missing data
!        06/09/01 - Major changes in control file.  Include response 
!                   spectral data.
!        06/15/01 - Added reading of Fourier amplitude spectra
!        10/19/01 - Obtain default name of control file via CR
!        11/13/01 - Increase number of files to 72 (3*24), so can plot
!                   spectra from 24 stations on one draw plot (3-components
!                   per plot).
!        02/25/02 - Allow for output of relative velocity or absolute 
!                   acceleration and print out type of response spectrum
!        04/15/02 - Increase format for printing imax to screen
!        05/06/02 - Added "!" as first character of each line of the headers
!                   so can read using skipcmnt.for
!        12/09/02 - Obtain nper for RS files from the file, rather than
!                   assuming nper_max = 100
!        02/11/03 - Increase field size for time columns
!        11/03/03 - Replace "isign_ts" with "xfactr" to allow scaling by a
!                   number; can be used to change the units or the sign of the 
!                   time series values.  Use +1.0 or -1.0 to duplicate the 
!                   use of isign_ts.
!        11/12/03 - Use trim_c to eliminate blanks in file names (important
!                   for use with LF95 compile and longer file names).
!        11/12/03 - Also, use buf4 to check for "STOP" or "PP:", so do not have 
!                   to convert buf to upper case.
!        11/13/03 - Allow for longer file names in column header by using 
!                   the (up to) 8 characters to the left of the last period.
!                   This was necesary because I was dealing with some file names
!                   that had a common string at the beginnig of the name, so
!                   all the column headings were identical
!        12/03/03 - Add new parameter to control file to determine if use
!                   first or last part of file name as a column header.  This 
!                   change is motivated by the longer file names being
!                   created by program BLPadFlt
!        01/26/07 - Allow for longer input file names
!        10/16/07 - Allow for higher precision smc files
!        10/24/08 - Change y output from e14.5 to e14.7 to be consistent with 
!                   higher precision smc files.
!        06/14/10 - Allow bigger npy, sps in writing headers n output file.
!        12/29/10 - Recompile, because fs2read now allows for higher precision smc format
!        02/07/11 - Increase length of file names
!        07/03/13 - Allow 4 decimal places for time output
!        05/04/17 - Modifications to avoid **** in output.
!                 - Replaced "float" with the generic function "real"
!                 - Replaced "tlength(i) = real(npy(i)-1)/sps(i)" with
!                            "tlength(i) = real(npy(i))/sps(i)", which is consistent with smcread.
!                 - Used "es" format to avoid using 1p and 0p

      parameter(ny_max = 72)
      parameter(nper_max = 300)
!      parameter(ny_max = 30)
      real y(:,:), sps(ny_max), tshift(ny_max), 
     :     tskip(ny_max), tlength(ny_max)
      real spsb4(ny_max), tlengthb4(ny_max)
      allocatable :: y

      real rd(nper_max,5), rv(nper_max,5), 
     :     psv(nper_max,5), aa(nper_max,5)
      real tprd(nper_max,5), tprv(nper_max,5), tpaa(nper_max,5)
      real damp(5), per(nper_max,ny_max)

      integer npy(ny_max), npyb4(ny_max), 
     :        ndecim(ny_max)
      real real_head(50), damp_rs(ny_max)
      real flow(ny_max), df_fas(ny_max), xfactr(ny_max)
      integer int_head(48), nc_f_y(ny_max), itype_rs(ny_max)
      character char_head(11)*80, comments(500)*80, cmnt_ctl(100)*80
      character f_ctl*200, f_out*200, f_y(ny_max)*200, buf*200, buf4*4,
     :  colhead(ny_max)*25, x_c(ny_max)*10, y_c(ny_max)*14, 
     :  path*40, comp_c*1, frmt_c*21, xcol*10, sep_c*1, type_rs_c*3
      logical f_ctl_exist, f_y_exist, use_first
      logical a_time_series(ny_max), a_resp_spect(ny_max),
     :        a_fourier_spect(ny_max)

      do i = 1, ny_max
        a_time_series(i) = .false.
        a_resp_spect(i) = .false.
        a_fourier_spect(i) = .false.
      end do

!      npy_max = 100000            ! depends on dimensions statement

! DEBUG
      call get_lun(nu_debug)
      open(unit=nu_debug, file='debug.out', status='unknown')
! DEBUG



! Get name of input file:
      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr=SMC2ASC.CTL;'//
     :    ' ctl-brk to quit): '
        read(*, '(a)') f_ctl
        if (f_ctl(1:4) .eq. '    ') f_ctl = 'smc2asc.ctl'
        call trim_c(f_ctl,nc_f_ctl)
        inquire(file=f_ctl(1:nc_f_ctl), exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do

! Open file 
      call get_lun(nu_ctl)      
      open(unit=nu_ctl, file=f_ctl(1:nc_f_ctl), status='unknown')

! Skip header lines:
      call skipcmnt(nu_ctl,cmnt_ctl,ncmnt_ctl)

! Read output file name:
      f_out = ' '
      read(nu_ctl, '(a)') f_out
      call trim_c(f_out,nc_f_out)

! Read variable to control blank or 1e37 (iblank = 1 ==> blank):
!   Skip text lines:
      call skipcmnt(nu_ctl,cmnt_ctl,ncmnt_ctl)
      read(nu_ctl, *) iblank

! Read variable specifying what part of file name is used in column header:
      call skipcmnt(nu_ctl,cmnt_ctl,ncmnt_ctl)
      buf = ' '
      read(nu_ctl, '(a)') buf
      call trim_c(buf,nc_buf)
      buf4 = ' '
      buf4 = buf(1:4)
      call upstr(buf4)
      if (buf4(1:1) .eq. 'F') then
        use_first = .true.
      else
        use_first = .false.
      end if

!  Skip text lines:
      call skipcmnt(nu_ctl,cmnt_ctl,ncmnt_ctl)

! Loop over time series:
      ny = 0
      nrs = 0
      nfs = 0
      nts = 0
1000  continue

! Read file name:
        buf = ' '
        read(nu_ctl, '(a)') buf
        call trim_c(buf,nc_buf)
        buf4 = ' '
        buf4 = buf(1:4)
        call upstr(buf4)

! Check for "STOP":
        if (buf4(1:4) .eq. 'STOP') go to 2000

! Check for processing parameter line:
        if(buf4(1:3) .eq. 'PP:') then !line contains processing params
! DEBUG
        write(nu_debug,'(a)') '  processing line: '
        write(nu_debug,'(2x,a)') buf(1:nc_buf)
! DEBUG
          call rci(2,buf,nc_buf,ndecim_in,ibgn1,iend1,istat1)
          call rcf(3,buf,nc_buf,tskip_in,ibgn2,iend2,istat2)
          call rcf(4,buf,nc_buf,tlength_in,ibgn3,iend3,istat3)
          call rcf(5,buf,nc_buf,xfactr_in,ibgn4,iend4,istat4)
!          call rci(5,buf,nc_buf,isign_y_in,ibgn4,iend4,istat4)
          call rcf(6,buf,nc_buf,tshift_in,ibgn5,iend5,istat5)
! DEBUG
        write(nu_debug,'(a)') 
     :  ' ndecim_in, tskip_in, tlength_in, xfactr_in, tshift_in:'
        write(nu_debug,*) 
     :    ndecim_in, tskip_in, tlength_in, xfactr_in, tshift_in
        write(nu_debug, '(a)') ' ibgn1, ibgn2, ibgn3, ibgn4, ibgn5 = '
        write(nu_debug, *) ibgn1, ibgn2, ibgn3, ibgn4, ibgn5
        write(nu_debug, '(a)') ' iend1, iend2, iend3, iend4, iend5 = '
        write(nu_debug, *) iend1, iend2, iend3, iend4, iend5
        write(nu_debug, '(a)') 
     :             ' istat1, istat2, istat3, istat4, istat5 = '
        write(nu_debug, *) istat1, istat2, istat3, istat4, istat5
! DEBUG
          go to 1000
        end if

! Check for ny > max number
        if (ny + 1 .gt. ny_max) then
           write(*,*)
           write(*, '(a   )') 
     :    ' ny+1 > ny_max; ignoring remaining y'
           write(*,*)
           go to 2000
        end if

! Passed tests; proceed
        ny = ny + 1
        f_y(ny) = ' '
        f_y(ny) = buf(1:nc_buf)
        call trim_c(f_y(ny), nc_f_y(ny))
        inquire(file=f_y(ny)(1:nc_f_y(ny)), exist=f_y_exist)
        if (.not. f_y_exist) then
          write(*,'(3a)') ' ****** FILE ', f_y(ny), 
     :          ' DOES NOT EXIST; QUITTING!!! ******* '
          close(nu_out)
          close(nu_ctl)
          stop
        end if

        write(*,'(2a)') '  f_y = ', f_y(ny)

! Get various information from headers:
        call ReadHdrs(f_y(ny)(1:nc_f_y(ny)), 
     :                char_head, int_head, real_head, comments)

! DEBUG
        write(nu_debug,'(a)') 
     :  ' After ReadHdrs: '//
     :  'ny, ndecim_in, tskip_in, tlength_in, xfactr_in, tshift_in:'
        write(nu_debug,*) 
     :    ny, ndecim_in, tskip_in, tlength_in, xfactr_in, tshift_in
! DEBUG

        if(char_head(1)(1:1) .eq. '5') then     ! Response spectra
          nrs = nrs + 1
          a_resp_spect(ny) = .true.
          itype_rs(ny) = ndecim_in
          damp_rs(ny) = tskip_in
! DEBUG
          write(nu_debug,'(a)') ' For file '//f_y(ny)(1:nc_f_y(ny))
          write(nu_debug,'(a)') 
     :      '   ny, nrs, itype_rs, damp_rs = '
          write(nu_debug,*) 
     :          ny, nrs, itype_rs(ny), damp_rs(ny)
! DEBUG

          call rs2rdhdr(f_y(ny)(1:nc_f_y(ny)), 
     :        damp, ndamp, per(1,ny), nper,  
     :        char_head, int_head, real_head, comments, itflag)
          npy(ny) = nper
          write(nu_debug,'(a,1x,i5,1x,i5)') 
     :    ' After rs2rdhdr: ny, npy(ny) = ',
     :                                      ny, npy(ny)
        else if(char_head(1)(1:1) .eq. '6') then  ! Fourier spectra
          nfs = nfs + 1
          a_fourier_spect(ny) = .true.
! DEBUG
          write(nu_debug,'(a)') ' For file '//f_y(ny)(1:nc_f_y(ny))
          write(nu_debug,'(a)') 
     :      '   ny, nfs = '
          write(nu_debug,*) 
     :          ny, nfs
! DEBUG
          npy(ny) = int_head(45)
        else
          nts = nts + 1
          a_time_series(ny) = .true.
          ndecim(ny) = ndecim_in          
          xfactr(ny) = xfactr_in
          tskip(ny) = tskip_in
          tlength(ny) = tlength_in
          tshift(ny) = tshift_in

! DEBUG
          write(nu_debug,'(a)') ' For file '//f_y(ny)(1:nc_f_y(ny))
          write(nu_debug,'(a)') 
     :       '   ny, nts, ndecim, tskip, tlength, '//
     :          'xfactr(ny), tshift = '
          write(nu_debug,*)
     :        ny, nts, ndecim(ny), tskip(ny), tlength(ny), 
     :           xfactr(ny), tshift(ny)
! DEBUG
          npy(ny) = int_head(17)
        end if

        inull = int_head(1)
        ivert = int_head(13)
        if (ivert .eq. inull .or. ivert .eq. 90) then
          comp_c = 'H'
        else
          comp_c = 'V'
        end if

! DEBUG
        write(nu_debug,'(a,2(1x,i6))') ' ny, npy(ny) = ', ny, npy(ny)
! DEBUG

        call get_path_from_file_name(f_y(ny),nc_f_y(ny),path,nc_path)

! DEBUG
        write(nu_debug,'(a,1x,i6)') ' nc_path = ', nc_path
! DEBUG

! Set up the column headings:
        xcol = ' '
        if (a_time_series(ny)) then
          xcol = '      time'
        else if (a_resp_spect(ny)) then
          xcol = '    period'
        else if (a_fourier_spect(ny)) then
          xcol = '      freq'
        end if

! Set separator to type of response spectra, if response spectra; otherwise
! blank:
        if (.not. a_resp_spect(ny)) then
          sep_c = '_'
        else
          if (itype_rs(ny) .eq. 0) sep_c = 'd'
          if (itype_rs(ny) .eq. 1) sep_c = 'v'
          if (itype_rs(ny) .eq. 2) sep_c = 'a'
        end if

        colhead(ny) = ' '
        colhead(ny)(1:10) = xcol

! Find last period:
!        do i = nc_f_y(ny), 1, -1
!          if (f_y(ny)(i:i) .eq. '.') then
!            indexp = i
!            go to 456
!          endif
!          indexp = 1
!        end do
!456     continue
!        index1 = indexp - 8
!        if (index1 .le. 0) index1 = 1
!        colhead(ny)(11:24) = f_y(ny)(index1:indexp-1)//
!     :                 sep_c//comp_c//'............'
!        colhead(ny)(11:24) = f_y(ny)(nc_path+1:nc_f_y(ny))//
!     :                 sep_c//comp_c//'............'

        if (use_first) then
          n2 = min0(nc_f_y(ny)-nc_path, 12)
          colhead(ny)(12:25) = f_y(ny)(nc_path+1:nc_path+n2)
     :            //sep_c//comp_c//'..............'
        else
          n1 = max0(nc_f_y(ny)-11, 1)
          colhead(ny)(12:25) = f_y(ny)(n1:nc_f_y(ny))
     :            //sep_c//comp_c//'..............'
        end if

        write(*,'(2a)') ' colhead = ', colhead(ny)

        go to 1000  ! loop back for another file

2000  continue

      close(unit=nu_ctl)

! Figure out largest value of npy and allocate the array:
      call imnmax(npy,1,ny,1,imin,imax) 
      write(*,*)
      write(*, '(a, 2(1x,i7))') ' imin, imax = ', imin, imax
      write(*, '(a, 2(1x,i7))') ' ny,ny_max = ', ny, ny_max

      allocate( y(imax,ny_max))

! Now read the data from the files:
     
        do i = 1, ny
          if (a_time_series(i)) then
!DEBUG
       write(nu_debug,'(a)') 
     :          ' Before SMCRead: file '//f_y(ny)(1:nc_f_y(ny))
       write(nu_debug,'(a,1x,i5)') 
     :          ' Before SMCRead: ny= ', ny
            call SMCRead(f_y(i)(1:nc_f_y(i)), tskip(i), tlength(i),
     :               y(1,i),  
     :               char_head, int_head, real_head, comments)
       write(nu_debug,'(a)') ' After SMCRead: '//f_y(ny)(1:nc_f_y(ny))
            npy(i) = int_head(17)
            sps(i) = real_head(2)
       write(nu_debug,'(a,1x,i2,1x,i5,1x,f5.1)') 
     :     ' After SMCRead: i, npy(i), sps(i) = ',
     :     i, npy(i), sps(i)       
! DEBUG
          write(*,*) ' Inside smc2asc. f_y  = ', 
     :                 f_y(i)(1:nc_f_y(i)) 
          write(*,*) ' Inside smc2asc. tskip(i), tlength(i) = ', 
     :                 tskip(i), tlength(i)
          write(*,*) 
     :  ' Inside smc2asc. i, ny, a_time_series(i), npy(i), sps(i) = ', 
     :                    i, ny, a_time_series(i), npy(i), sps(i)
          write(*,*) ' Inside smc2asc. f_y, y(1) = ', 
     :                 f_y(i)(1:nc_f_y(i)), y(1,i)
! DEBUG

! Decimate:
            npyb4(i) = npy(i)
            spsb4(i) = sps(i)
            tlengthb4(i) = real(npyb4(i))/spsb4(i)
            nt = 0
            do j = 1, npy(i), ndecim(i)
              nt = nt + 1
              y(nt,i) = xfactr(i) * y(j,i)
            end do
            npy(i) = nt
            sps(i) = sps(i)/real(ndecim(i))
            tlength(i) = real(npy(i))/sps(i)
          else if (a_fourier_spect(i)) then
            call FS2Read(f_y(i), 
     :                   y(1,i), 
     :                   char_head, int_head, real_head, comments)
            npy(i) = int_head(45)
            flow(i) = real_head(42)
            df_fas(i) = real_head(44)
          else if (a_resp_spect(i)) then
            call rs2read(f_y(i), 
     :        damp, ndamp, per(1,i), nper, rd, rv, psv, aa, 
     :        char_head, int_head, real_head, comments,
     :        itflag, tprd, tprv, tpaa)
            iset_rs = 0
            npy(i) = nper
            do idamp = 1, ndamp
              if(damp(idamp) .eq. damp_rs(i)) then
                twopi = 2.0 * 4.0 * atan(1.0)
! DEBUG
             write(nu_debug,'(a,1x,i2,1x,f7.3,1x,i1)')
     :             '  i, damp, itype_rs = ',
     :                i, damp_rs(i), itype_rs(i)
! DEBUG
                do iper = 1, nper
                  if (itype_rs(i) .le. 2) then
                    romega = twopi/per(iper,i)
                    y(iper,i) = romega**itype_rs(i) * rd(iper, idamp)
                    iset_rs = 1
                  else if (itype_rs(i) .eq. 3) then
                    y(iper,i) = rv(iper, idamp)
                    iset_rs = 1
                  else if (itype_rs(i) .eq. 4) then
                    y(iper,i) = aa(iper, idamp)
                    iset_rs = 1
                  else                 
                    write(*,'(a,1x,i3,a)') 
     :               '  ERROR: itype_rs = ', itype_rs(i), 
     :               ' not valid; QUITTING!!!'
                    close(nu_ctl)
                    stop
                  end if
                end do
              end if    
            end do
            if (iset_rs .ne. 1) then
              write(*,'(a)') '  ERROR: Response spectra for damping '//
     :                       ' not found; QUITTING!!!'
              close(nu_ctl)
              stop
            end if
          else
            write(*,'(a)') '  Problem: should not have reached here; '//
     :                     'Quitting!!!'
            stop
          end if

        end do

! Write output:

! Open output file:

      write(*,*)
      write(*,'(a)') ' Writing output file: '//f_out(1:nc_f_out)

      call get_lun(nu_out)      
      open(unit=nu_out, file=f_out, status='unknown')



      write(nu_out, '(a,1x,i4)') 
     :     '! Number of variables = ', 2*ny
      write(nu_out, '(a,1x,i4)') 
     :     '! Variable names start on line # ', 
     :      4+4*nts+2*nrs+2*nfs+1
      write(nu_out, '(a,1x,i4)') 
     :     '! Data starts on line # ', 
     :      4+4*nts+2*nrs+2*nfs+2

      write(nu_out, '(2a)') '! File with input parameters: ', f_ctl
 
      do i = 1, ny
        if (a_time_series(i)) then
          write(nu_out, '(2a)') 
     :      '! File with time series: ',f_y(i)
          write(nu_out, '(a,i5,1x,f7.3,1x,f8.1,1x,es10.3,
     :        1x,f7.3)') 
     :      '!  ndecim, tskip, tlength, xfactr, tshift = ',
     :        ndecim(i), tskip(i), tlength(i), xfactr(i), tshift(i)        
          write(nu_out, '(a, i7, 1x,es12.5, 1x,es12.5)') 
     :      '!  Before decimation: npy, sps, tlength = ', 
     :        npyb4(i), spsb4(i), tlengthb4(i)
          write(nu_out, '(a, i7, 1x,es12.5, 1x,es12.5)') 
     :      '!  After decimation: npy, sps, tlength = ', 
     :        npy(i), sps(i), tlength(i)
        else if (a_fourier_spect(i)) then
          write(nu_out, '(2a)') 
     :      '! File with Fourier spectra: ',f_y(i)
          write(nu_out, '(a,2(1x,es10.3))') 
     :      '!  flow, df_fas = ',
     :        flow(i), df_fas(i)
        else if (a_resp_spect(i)) then
          type_rs_c = ' '
          if (itype_rs(i) .eq. 0) then
            type_rs_c = ' RD'
          else if (itype_rs(i) .eq. 1) then
            type_rs_c = 'PSV'
          else if (itype_rs(i) .eq. 2) then
            type_rs_c = 'PSA'
          else if (itype_rs(i) .eq. 3) then
            type_rs_c = ' RV'
          else if (itype_rs(i) .eq. 4) then
            type_rs_c = ' AA'
          end if

          write(nu_out, '(2a)') 
     :      '! File with response spectra: ',f_y(i)
          write(nu_out, '(a,1x,f5.2)') 
     :      '!  itype_rs, damp_rs = '//type_rs_c, damp_rs(i)
        end if
      end do

      frmt_c = ' '
      frmt_c = '(xx(a25))'
      write(frmt_c(2:3), '(i2)') ny

      write(nu_out, frmt_c) 
     :    (colhead(j), j = 1, ny)
      
      frmt_c = ' '
      frmt_c = '(xx(a,1x,a))'
      write(frmt_c(2:3), '(i2)') ny

! Find new imax:
      call imnmax(npy,1,ny,1,imin,imax) 

      do i = 1, imax

! Account for unequal number of points:
        do j = 1, ny
          if (i .le. npy(j)) then              ! fill output string with value
            if(a_time_series(j)) then
              write(x_c(j), '(1x,f9.4)') real(i-1)/sps(j)+tshift(j)
            else if(a_fourier_spect(j)) then
              write(x_c(j), '(1x,f9.4)') 
     :          real(i-1)*df_fas(j)+flow(j)
            else if(a_resp_spect(j)) then
              write(x_c(j), '(1x,f9.4)') per(i,j)
            end if

            write(y_c(j), '(es14.7)') y(i,j)
!            write(y_c(j), '(es14.5)') y(i,j)

! Note: best if could use blanks, but CoPlot does not import this
! correctly as wrapped ascii.  It would import properly if I made
! a column file, but I am reluctant to strip off the informative header lines 

          else                                  ! fill with blanks
            x_c(j) = ' '
            if (iblank .eq. 1) then
              y_c(j) = ' '
            else                                  ! fill with very large number
              write(y_c(j), '(es14.7)') 1.0e37
!              write(y_c(j), '(es14.5)') 1.0e37
            end if
          end if
        end do
        write(nu_out, frmt_c) (x_c(j),y_c(j), j = 1, ny)
      end do

      deallocate(y)

      close(unit=nu_out)

      stop
      end
! ------------------ END SMC2ASC -----------------------------

      include '\forprogs\SMCRead.for'
      include '\forprogs\rs2Rdhdr.for'
      include '\forprogs\rs2Read.for'
      include '\forprogs\fs2Read.for'
      include '\forprogs\readhdrs.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\imnmax.for'
      include '\forprogs\skipcmnt.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\upstr.for'
      include '\forprogs\rc_subs.for'
      include '\forprogs\get_path_from_file_name.for'


