* ----------------- BEGIN smc2rs_col_output_transposed ---------------------------
      Program smc2rs_col_output_transposed

* Reads a list of files containing response spectra for a set of periods and a single station,
! and write an output file with each column being the response spectral values for 
! a single period and each row being the response spectra for a single station.   
! AN IMPORTANT ASSUMPTION is that the periods are the same for each input file.

*! Control file for program smc2rs_col_output_transposed
*! Revision of program involving a change in the control file on this date:
*   04/25/11
*!Name of output file
*   rs_col_output_transposed_psa.out
*!Number of columns to read, column with period, column with response spectra
* 5 1 5
*!List of files containing response spectra (from smc2rs):
*dcky.a01.rs.col
*dcky.a03.rs.col
*emme.a01.rs.col
*emme.a03.rs.col
* stop
  
* Dates: 04/25/11 - Written by D.M. Boore 
   
      character  ctl_cmmnts(60)*100

 

      character f_control*200, f_rs*200, f_out*200
      character version_ctl*8, version_in*30
     
      character buf*3500, buf4*10

      real :: per4colheads(200), period(200), rs(200), dum(200)
      
      integer status
      
      logical file_exist
       
      get name of control file: DO
        file_exist = .false.
        f_control = ' '
        write(*, '(a)') 
     :    ' Enter name of control file '//
     :    '(cr = smc2rs_col_output_transposed.ctl; ctl-brk to quit): '
        read(*, '(a)') f_control
        if (f_control(1:4) .eq. '    ') 
     :    f_control = 'smc2rs_col_output_transposed.ctl'
        call trim_c(f_control, nc_f_control)
        inquire(file=f_control(1:nc_f_control), exist=file_exist)
        if (.not. file_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
          CYCLE get name of control file
        else
          EXIT get name of control file
        end if
      END DO get name of control file
      
      call get_lun(nu_ctl)
      open(unit=nu_ctl,file=f_control(1:nc_f_control),
     :     status='unknown')

*Check version of control file
      call skipcmnt(nu_ctl,ctl_cmmnts, nc_ctl_cmmnts)
      version_in = ' '
      read(nu_ctl,'(a)') version_in
      call trim_c(version_in,nc_version_in)
      
      version_ctl = ' '
      version_ctl = '04/25/11'
      call trim_c(version_ctl,nc_version_ctl)

      if (version_ctl(1:nc_version_ctl) .ne. 
     :    version_in(1:nc_version_in)) then
        write(*,'(a)') 
     :     ' The control file has the wrong version number; STOP!'
        close(nu_ctl)
        stop
      end if
      

!Get output file name:
      call skipcmnt(nu_ctl,ctl_cmmnts, nc_ctl_cmmnts)
      f_out = ' '
      read(nu_ctl, '(a)') f_out
      call trim_c(f_out, nc_f_out)
      call get_lun(nu_out)
      open(unit=nu_out,file=f_out(1:nc_f_out),
     :     status='unknown')

!Number of columns to read, column with period, column with response spectra:
      call skipcmnt(nu_ctl,ctl_cmmnts, nc_ctl_cmmnts)
      read(nu_ctl,*) ncol2read, icolper, icolrs

      call skipcmnt(nu_ctl,ctl_cmmnts, nc_ctl_cmmnts)

      n_events = 0

!Loop over response spectral files (one for each record):
      get_rs_file_name_loop: DO
      
        buf = ' '
        read(nu_ctl,'(a)',IOSTAT=status) buf
 
        if (status /= 0) EXIT  ! could not read buf
        call trim_c(buf, nc_buf)
        buf4 = ' '
        buf4(1:4) = buf(1:4)
        call upstr(buf4)
        if (buf4 == 'STOP') EXIT
        
        f_rs = ' '
        f_rs = buf(1:nc_buf)
        call trim_c(f_rs,nc_f_rs)
        file_exist = .false.
        inquire(file=f_rs(1:nc_f_rs), exist=file_exist)
        if (.not. file_exist) then
          write(*,'(a)') ' ******* FILE '//f_rs(1:nc_f_rs)//
     :    ' DOES NOT EXIST *******; Cycle to another one '          
          cycle
        end if
        call get_lun(nu_rs)
        open(unit=nu_rs,file=f_rs(1:nc_f_rs),
     :     status='unknown')
     
        n_events = n_events + 1
        
        print *,' working on data in file '//f_rs(1:nc_f_rs)
        
        call skip(nu_rs, 1)
        period = 0.0
        rs = 0.0
        dum = 0.0
        nper = 0
        loop over periods: DO
          read(nu_rs,*,IOSTAT=status) (dum(i), i = 1, ncol2read)
          if (status /= 0) EXIT loop over periods ! finished with this file
          nper = nper + 1
          period(nper) = dum(icolper)
          rs(nper) = dum(icolrs)
        END DO loop over periods
        
        IF (n_events == 1) THEN
          nper4colhead = nper
          DO i = 1, nper
           per4colheads(i) = period(i)
          END DO
          write(nu_out,'(40x,a,100(6x,f7.3))') 'filename/T',
     :          (per4colheads(i), i = 1, nper)
        END IF 
        
! Check periods:
        IF (nper4colhead /= nper) THEN
          write(*,*) ' ERROR, nper not equal; cycle'
          CYCLE get_rs_file_name_loop 
        END IF
        DO i = 1, nper
          IF ( per4colheads(i) /= period(i)) THEN
            write(*,*) ' ERROR, periods not equal; cycle'
            CYCLE get_rs_file_name_loop 
          END IF
        END DO
        
        nc4output = min0(nc_f_rs, 50)
        write(nu_out,'(a50,100(1x,es12.5))')
     :       f_rs(1:nc4output), (rs(i), i = 1, nper)
 

          
! Loop back for another set of Data:

        close(nu_rs)

      END DO get_rs_file_name_loop ! loop back for another set of input parameters

 

      close(nu_ctl)
      close(nu_out)

      stop
      end
* ----------------- END smc2rs_col_output_transposed ---------------------------

      include '\forprogs\skip.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\upstr.for'
      include '\forprogs\skipcmnt.for'
   