* ------------------------------------------------------------------ smc_sta
      Program smc_sta

* Reads a list of smc files, and for each it extracts station information
* and prints it to two files: 1) a summary file; and 2) a file in comma
* delimited format for import into data base programs.

* The list of files can have multiple files for one station (as would 
* occur when dir/on/b *.smc > smc.lst is used, for example).  The following
* events trigger the output of a line:
* new station number
* new lat
* new long
* new station name
* new inst type

* Here is a sample control file:
*Control file for program smc_sta:
*Name of summary output file (suggest *.col):
* smc_sta.col
*Name of comma delimited output file (suggest *.txt, to import into Paradox):
* smc_sta.txt
*List of files:
*file1.smc
*file2.smc
*file3.smc
*stop

*  Dates:  10/26/00 - Written by D. Boore, modified from CDRomLst
*          12/08/00 - Renamed from sta_info; struggling with comparison
*                     of strings.  The problem was that in some smc files
*                     the inst_type was stored in columns beyond col. 15,
*                     which is a violation of the smc format.  I dealt with
*                     this by allowing the string to be in columns 11:20
*                     (and making the length of inst_type = 10)
*          12/22/00 - Allow for blank inst type by setting inst_type = 'blank'
*                     in Get_Info
*          12/27/00 - Include data source in lat, long column headers
*          01/04/01 - Add quake name to output
*        10/17/07 - Transparent change to user needed because smcread can
*                   read two input formats


      character f_comma*40, f_sum*40, 
     :          f_name*20, f_name_new*20, 
     :          quake_name*54, sta_name*30, sta_name_new*30,
     :          inst_type*10, inst_type_new*10,
     :          data_source*45, data_source_new*45

      real sta_lat, sta_lat_new, sta_long, sta_long_new

      character f_ctl*40
      logical f_ctl_exist

      iflag_first = 0

      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr to quit): '
        read(*, '(a)') f_ctl
        if (f_ctl .eq. ' ') stop
        inquire(file=f_ctl, exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do

      call get_lun(nu_ctl)
      open(unit=nu_ctl,file=f_ctl,status='unknown')

      call skip(nu_ctl, 2)

*  Get the name of summary output file:

      f_sum = ' '
      read(nu_ctl,'(a)') f_sum
      write(*,'(2a)') ' f_sum = ', f_sum
      call get_lun(nu_sum)
      open (unit=nu_sum, file=f_sum, status='unknown')

*  Get the name of comma-delimited output file:

      call skip(nu_ctl,1)

      f_comma = ' '
      read(nu_ctl,'(a)') f_comma
      write(*,'(2a)') ' f_comma = ', f_comma
      call get_lun(nu_comma)
      open (unit=nu_comma, file=f_comma, status='unknown')

* Read the control file, line by line:

      call skip(nu_ctl,1)  ! position to first entry

      call GetInfo(nu_ctl, f_name, quake_name, sta_name, 
     :             i_rcrdr, inst_type, 
     :             data_source, id_sta, 
     :             sta_lat, sta_long, iflag_stop)

1000  continue

      call GetInfo(nu_ctl, f_name_new, quake_name, sta_name_new, 
     :             i_rcrdr_new, inst_type_new, 
     :             data_source_new, id_sta_new, 
     :             sta_lat_new, sta_long_new, iflag_stop)

      if (iflag_stop .eq. 1) then
         call Output(iflag_first, nu_sum, nu_comma, f_name, 
     :               quake_name, sta_name, 
     :               i_rcrdr, inst_type,
     :               data_source, id_sta, sta_lat, sta_long)
         close(nu_sum)
         close(nu_comma)
         close(nu_ctl)
         stop
      end if

* Check if a new station.  If so, write info from previous station and reset:

      call trim_c(sta_name_new,nc_sn_n)
      call trim_c(sta_name,nc_sn)
      call trim_c(inst_type_new,nc_it_n)
      call trim_c(inst_type,nc_it)
      call trim_c(data_source_new,nc_ds_n)
      call trim_c(data_source,nc_ds)

      if (sta_name_new(1:nc_sn_n)    .ne. sta_name(1:nc_sn)    .or.
     :    inst_type_new(1:nc_it_n)   .ne. inst_type(1:nc_it)   .or.
     :    data_source_new(1:nc_ds_n) .ne. data_source(1:nc_ds) .or.
     :    id_sta_new                 .ne. id_sta               .or.
     :    sta_lat_new                .ne. sta_lat              .or.
     :    sta_long_new               .ne. sta_long)         then

         call Output(iflag_first, nu_sum, nu_comma, f_name, 
     :               quake_name, sta_name, 
     :               i_rcrdr, inst_type,
     :               data_source, id_sta, sta_lat, sta_long)
         f_name = ' '
         f_name = f_name_new
         sta_name = ' '
         sta_name = sta_name_new
         i_rcrdr = i_rcrdr_new
         inst_type = ' '
         inst_type = inst_type_new
         data_source = ' '
         data_source = data_source_new
         id_sta = id_sta_new
         sta_lat = sta_lat_new
         sta_long = sta_long_new
      end if

* Go back for a new file:
     
      go to 1000        

      end
* ------------------------------------------------------------------ smc_sta

* ------------------------------------------------------------------ GetInfo
      subroutine GetInfo(nu_ctl, f_name, quake_name, sta_name, 
     :             i_rcrdr, inst_type, 
     :             data_source, id_sta, sta_lat, sta_long, iflag_stop)

      character f_name*(*), quake_name*(*), sta_name*(*), 
     :          inst_type*(*), data_source*(*)
      character buf*80, f_smc*40

      real sta_lat, sta_long
      integer id_sta, iflag_stop  

      character char_head(11)*80, comments(50)*80
      integer int_head(48)
      parameter(iydimen=100)
      real real_head(50), y(iydimen)

      buf = ' '
      read (nu_ctl, '(a)') buf
      call upstr(buf)
      call trim_c(buf,nchar)
      if (buf(1:nchar) .eq. 'STOP') then  ! set iflag_stop to 1 and return
        iflag_stop = 1
        return
      end if
      iflag_stop = 0

      f_smc = ' '
      f_smc = buf(1:nchar)

      call SMC_NSPS(f_smc, npts, sps)

      if (sps .lt. 0.0) then
        tlength = 1.0
      else
        tlength = float(iydimen-1)/sps
      end if

      tskip = 0.0
      call SMCRead(f_smc, tskip, tlength,
     :                   y, char_head, int_head, real_head, comments)

      f_name = ' '
      f_name = f_smc
      quake_name = ' '
      quake_name = char_head(4)(27:80)
      sta_name = ' '
      sta_name = char_head(6)(11:40)
      i_rcrdr = int_head(8)
      inst_type = ' '
      inst_type = char_head(8)(11:20)  ! see comments of 12/08/00 in main prog
*      inst_type = char_head(8)(11:15)
      if (inst_type .eq. ' ') inst_type = 'blank'
      data_source = ' '
      data_source = char_head(8)(36:80)
      id_sta = int_head(30)
      sta_lat = real_head(11)
      sta_long = real_head(12)

      return
      end
* ------------------------------------------------------------------ GetInfo

* ------------------------------------------------------------------ OutPut
      subroutine Output(iflag_first, nu_sum, nu_comma, 
     :               f_name, quake_name, sta_name, 
     :               i_rcrdr, inst_type,
     :               data_source, id_sta, sta_lat, sta_long)

      character f_name*(*), sta_name*(*), inst_type*(*), 
     :          data_source*(*), source_lat*9, source_long*10,
     :          quake_name*(*)
      
      character buf*54

      real sta_lat, sta_long
      integer id_sta

      write(*,'(2a)') ' Inside Output: f_name = ', f_name
      write(*,'(2a)') ' sta_name = ', sta_name
      write(*,'(a, 1x,i5)') ' id_sta = ', id_sta
      write(*,'(a, 2(1x,f10.5))') 
     :  ' sta_lat, sta_long = ',
     :    sta_lat, sta_long

      write(*,'(2a)') ' data_source = ', data_source
      write(*,'(2a)') ' inst_type = ', inst_type

      call trim_c(f_name,nc_f_name)
      call trim_c(quake_name,nc_quake_name)
      call trim_c(sta_name,nc_sta_name)
      call trim_c(data_source,nc_data_source)
      call trim_c(inst_type,nc_inst_type)

      if (iflag_first .eq. 0) then
        iflag_first = 1
        if (nc_data_source .ge. 5) then
          source_lat = data_source(1:5)//'_lat'
          source_long = data_source(1:5)//'_long'
        else
          source_lat(6-nc_data_source:9) = 
     :         data_source(1:nc_data_source)//'_lat'
          source_long(6-nc_data_source:10) = 
     :         data_source(1:nc_data_source)//'_long'
        end if
        write(nu_sum,'(t8,"f_name", t16,"ins#", 
     :        t39,"station_name", t53,"sta#", 
     :        t59,a, t69,a, 
     :        t80,"datasource", t91,"instr",
     :        t141,"earthquake")') source_lat, source_long
      end if

      buf = ' '
      if (nc_quake_name .eq. 54) then
        buf = quake_name(1:nc_quake_name)
      else
        buf(1:54-nc_quake_name) = ' '
        buf(54-nc_quake_name + 1:54) = quake_name(1:nc_quake_name)
      end if

      write(nu_sum,'(1x,a12,1x,i5,1x,a30,
     :               1x,i5,2(1x,f10.5),
     :               1x,a10,1x,a5,1x,a54)') 
     : f_name(1:nc_f_name), i_rcrdr, sta_name(1:nc_sta_name), 
     : id_sta, sta_lat, sta_long, 
     : data_source(1:nc_data_source), inst_type(1:nc_inst_type),
     : buf

      write(nu_comma,'( ",""", i5,""",""",a,""",""", i5, """,", 
     :                 1x,f10.5,",", 1x,f10.5,
     :                 ",""", a, """,""", a, """,""", a, """")')
     :    i_rcrdr, sta_name(1:nc_sta_name), id_sta, 
     :    sta_lat, sta_long,
     :    data_source(1:nc_data_source), 
     :    inst_type(1:nc_inst_type), quake_name(1:nc_quake_name)

      return
      end
* ------------------------------------------------------------------ OutPut

      include '\forprogs\skip.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\upstr.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\smcread.for'
      include '\forprogs\smc_nsps.for'

   