* ---------------------------------------------------------------- smc_std
      Program smc_std

* Snip out a section of an SMC, compute the mean and standard deviation,
* and write the results as an ascii file.

* Input/output controlled by information in a control file.  Here is an example:

*!Control file for program SMC_STD
*! File name of output file:
* smc_std.out
*!f_smc_in tskip tlength f_smc_out ("STOP" in any column to quit)
* file1_in.smc 0.0  80.0
* file2_in.smc 0.0  80.0
* file3_in.smc 0.0  80.0
*StoP
* file4_in.smc 0.0  80.0

* Dates: 04/23/01 - Written by D. Boore, patterned after SMC_SNIP
*        07/17/03 - Add sps to smc_npts parameter list
*        10/17/07 - Transparent change to user needed because smcread can
*                   read two input formats

      character precision*8


      character f_smc_in*40, f_out*40
      character char_head(11)*80, comments(50)*80
      integer int_head(48)
      real real_head(50)
      real y(:)
      allocatable :: y
      character buf*80, cmmnts(20)*80

      character f_ctl*40
      logical f_ctl_exist

      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr to quit): '
        read(*, '(a)') f_ctl
        if (f_ctl .eq. ' ') stop
        inquire(file=f_ctl, exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do

      call get_lun(nu_ctl)
      open(unit=nu_ctl,file=f_ctl,status='unknown')

      call skipcmnt(nu_ctl, cmmnts, ncmmnts)

      f_out = ' '
      read(nu_ctl,'(a)') f_out
      call get_lun(nu_out)
      open(unit=nu_out,file=f_out,status='unknown')

      call skipcmnt(nu_ctl, cmmnts, ncmmnts)

1000  continue

      buf = ' '
      read(nu_ctl,'(a)') buf
      call upstr(buf)
      call trim_c(buf,nc_buf)
      if(buf(1:4) .eq. 'STOP') then
         close(nu_ctl)
         close(nu_out)
         stop
      end if

      write(*,'(3a,1x,i3)') 
     :  ' buf = ', buf(1:nc_buf), ' and nc_buf = ', nc_buf

      f_smc_in = ' '
      call RCC (1,buf,nc_buf,f_smc_in,nc_f_in,ibgn,iend)

      call smc_npts(f_smc_in, npts_max, sps)

      allocate (y(npts_max))
      
      call RCF (2,buf,nc_buf,tskip,ibgn,iend,istat)

      call RCF (3,buf,nc_buf,tlength,ibgn,iend,istat)

      call SMCRead(f_smc_in, tskip, tlength,
     :             y, char_head, int_head, real_head, comments)
     
      precision = ' '
      if (int_head(47) .eq. 8) then
        precision = 'HIGH'
      else
        precision = 'STANDARD'
      end if
      

      npts = int_head(17)
      write(*,'(a,1x,i5)') '   npts = ', npts
     
      call moment(y,npts,ave,adev,sdev,var,skew,curt)

      call mnmaxidx(y,1,npts,1,
     :                    ymin,ymax,indx_ymin,indx_ymax) 
      write(nu_out,'(2a)') ' f_smc_in = ', f_smc_in
      write(nu_out,'(a)') 
     :      '   tskip, tlength = '
      write(nu_out,*) tskip, tlength
      write(nu_out,'(a)') 
     :      '   npts, ave, sdev, var = '
      write(nu_out,*) npts, ave, sdev, var 

      write(nu_out,'(a)') 
     :      '   indx_ymin, indx_ymax, ymin-ave, ymax-ave = '
      write(nu_out,*) indx_ymin, indx_ymax, ymin-ave, ymax-ave 

      deallocate(y)

      go to 1000

      end
* ---------------------------------------------------------------- smc_std
      
      include '\forprogs\get_lun.for'
      include '\forprogs\mnmaxidx.for'
*      subroutine mnmaxidx(a,nstrt,nstop,ninc,
*     :                    amin,amax,indx_min,indx_max) 
      include '\forprogs\SMCRead.for'
      include '\forprogs\SMCWrite.for'
      include '\forprogs\rc_subs.for'
      include '\forprogs\upstr.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\skip.for'
      include '\forprogs\smc_npts.for'
      include '\forprogs\moment.for'
      include '\forprogs\skipcmnt.for'
*      subroutine skipcmnt(nu, comment, ncomments)

