! ------------------------------------------------------------------- SMCAdd2
      Program SMCAdd2


! Reads two smc files and adds one to another to create a third file.  Here
! is a sample control file:

!!Control file for program SMCAdd2
!! Add together two smc files with a specified time lag and
!! possible amplitude change (a polarity reversal is accomplished by using
!! a negative amplitude)
!!Names of the two SMC input files:
! 319A.SMC
! Butler Valley Sta. 2
!!Name of the SMC output file:
! smcadd2.smc
!! time lag for second file, amps of first and second files:
!  25.0 1.0 -0.5
!stop


! Dates: 07/17/03 - Written by D.M. Boore, patterned after SMC2VD
!        10/17/07 - Transparent change to user needed because smcread can
!                   read two input formats
!        02/13/20 - Modernize code, correct bug that long file names were truncated in 
!                   the text comments of the output file.

      character precision*8


c
c Dimension and declaration statements:

      real a(:,:)
!      real a(:,:), y(:)
      allocatable :: a
!      allocatable :: a, y

      integer nc_f_a(3)

      real sps(3), dt(3), tend(3)

      integer ncomments(3), npts(3)

      character date_c*8, time_c*11

      character char_head(11)*80, comments(500,3)*80, 
     :          cmnts2skip(50)*80
      real real_head(50), amp(2)
      integer int_head(48)

      character buf*80, buf_upper*4, f_a(3)*70

      character f_ctl*40
      logical f_ctl_exist, f_a_exist, rmv_trnd, use_v0_d0

      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr=SMCAdd2.CTL;'//
     :    ' ctl-brk to quit): '
        read(*, '(a)') f_ctl
        if (f_ctl(1:4) == '    ') f_ctl = 'smcadd2.ctl'
        inquire(file=f_ctl, exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do

      call get_lun(nu_ctl)
      open(unit=nu_ctl,file=f_ctl,status='unknown')

      call skipcmnt(nu_ctl,cmnts2skip,nc_cmnts2skip)

      do i = 1, 2
        f_a(i) = ' '
        read(nu_ctl,'(a)') f_a(i) 
        call trim_c(f_a(i),nc_f_a(i))
        write(*,'(a)') '   f_a(i) = '//f_a(i)(1:nc_f_a(i))
      end do

      call skipcmnt(nu_ctl,cmnts2skip,nc_cmnts2skip)

      f_a(3) = ' '
      read(nu_ctl,'(a)') f_a(3) 
      call trim_c(f_a(3),nc_f_a(3))
      write(*,'(a)') '   f_a(3) = '//f_a(3)(1:nc_f_a(3))

      call skipcmnt(nu_ctl,cmnts2skip,nc_cmnts2skip)

      read(nu_ctl,*) tlag, amp(1), amp(2)
      write(*,'(a)') ' tlag, amp(1), amp(2) = '
      write(*, *)      tlag, amp(1), amp(2)

! Get number of points in f1, f2 and allocate:

      do i = 1, 2
        call smc_npts(f_a(i)(1:nc_f_a(i)), npts(i), sps(i))
      end do

! Now figure out times and allocate the array

      write(*,'(a,1x,f8.4)') ' sps(1) = ', sps(1)

      nlag = tlag*sps(1)
      npts(3) = nlag+ npts(2)
      write(*,'(a)') ' nlag, npts(1), npts(2), npts(3) = ' 
      write(*, *)      nlag, npts(1), npts(2), npts(3)

      allocate( a(npts(3)+5,3) )
!      allocate( y(npts(3)+5) )

      do i = 1, 2

! Now read the data from the files:

        write(*,'(1x,a)') 
     :   'Processing file:', f_a(i)(1:nc_f_a(i))

        tskip = 0.0
        tlength = -1.0

!        call SMCRead(f_a(i)(1:nc_f_a(i)), tskip, tlength,
!     :               y,  
!     :               char_head, int_head, real_head, comments(1,i))

        call SMCRead(f_a(i)(1:nc_f_a(i)), tskip, tlength,
     :               a(1,i),  
     :               char_head, int_head, real_head, comments(1,i))

      precision = ' '
      if (int_head(47) == 8) then
        precision = 'HIGH'
      else
        precision = 'STANDARD'
      end if
      
        rnull = real_head(1)

        sps(i) = real_head(2)
        ncomments(i) = int_head(16)
        npts(i) = int_head(17)
        dt(i) = 1.0/sps(i)
        tend(i) = float(npts(i)-1)*dt(i)
! DEBUG
        write(*,'(a)') 
     :       ' i, sps(i), ncomments(i), npts(i), dt(i), tend(i) = '
        write(*, *) 
     :         i, sps(i), ncomments(i), npts(i), dt(i), tend(i)
! DEBUG
      end do

! Fill out the new array:

      do i = 1, npts(3)
        a(i,3) = 0.0
      end do

      do i = 1, npts(1)
        a(i,3) = amp(1)*a(i,1)
      end do

      do i = 1, npts(2)
        a(i+nlag,3) = a(i+nlag,3) + amp(2)*a(i,2)
      end do

! Step 3: Write output:

! DEBUG
      write(*,'(a)') ' Start output section'
! DEBUG


! Write acceleration:
      write(*,'(1x,a)') 
     :   'Writing acceleration output to file:', 
     :    f_a(3)(1:nc_f_a(3))

      iflag = 0 ! not used by current PC version of datetime; Chris
                ! Stephens would modify datetime.for to include Unix routines
      call datetime(date_c, time_c, iflag)

      ncomments(3) = 0
      do i = 1, 2
        do j = 1, ncomments(i)
          comments(ncomments(3) + j,3) = comments(j,i)
        end do
        ncomments(3) = ncomments(3) + ncomments(i)       
      end do

      ncomments(3) = ncomments(3) + 1
      comments(ncomments(3), 3) = '|'

      ncomments(3) = ncomments(3) + 1
      comments(ncomments(3),3) = 
     :      '| Using program SMCAdd2, add together files '

      ncomments(3) = ncomments(3) + 1
      comments(ncomments(3),3) = '| '//f_a(1)(1:nc_f_a(1)) 

      ncomments(3) = ncomments(3) + 1
      comments(ncomments(3),3) = '| and '

      ncomments(3) = ncomments(3) + 1
      comments(ncomments(3),3) = '| '//f_a(2)(1:nc_f_a(2))

      ncomments(3) = ncomments(3) + 1
      comments(ncomments(3),3) = 
     :      '|   on '//date_c//' at time '//time_c

      ncomments(3) = ncomments(3) + 1
      write(comments(ncomments(3),3),'(a,1x,f6.2,1x,f6.3,1x,f6.3)') 
     :      '|   with tlag, amp(1), amp(2) = ', tlag, amp(1), amp(2) 

      ncomments(3) = ncomments(3) + 1
      comments(ncomments,3) = '|   resulting in output file '//
     :      f_a(3)(1:nc_f_a(3))

      ncomments(3) = ncomments(3) + 1
      comments(ncomments,3) = '|'

      int_head(16) = ncomments(3) 
      int_head(17) = npts(3)
      itype = -1 ! use input

      call SMCWrite(f_a(3)(1:nc_f_a(3)), precision,
     :                a(1,3), char_head, itype, 
     :                    int_head, real_head, comments(1,3))


      deallocate (a)

! Close control and output files:

      close(nu_ctl)

      stop
      end
! ------------------------------------------------------------------- SMC2VD


      include '\forprogs\distaz.for'
      include '\forprogs\skip.for'
      include '\forprogs\skipcmnt.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\upstr.for'
      include '\forprogs\smc_npts.for'
      include '\forprogs\smcread.for'
      include '\forprogs\smcwrite.for'
      include '\forprogs\acc2vd.for'
      include '\forprogs\Trapezoidal_Integration.for'
      include '\forprogs\imnmax.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\rc_subs.for'
      include '\forprogs\datetime.for'
      include '\forprogs\rmvtrend.for'
      include '\forprogs\mnmaxidx.for'
