
* ---------------------------------------------------------------- SMCAddSN
       Program SMCAddSN

* Reads station number from text header(3)(1:4), checks to make sure
* it is not blank or does not contain noninteger characters, and if
* it passes these tests, it is written into int_header(30).

* Note that this assumes that the stacode is only 4 integers.  This is not true
* for csmip data, but for that data I use cdmgv2gs.for to reformat into
* smc format, and then the station codes are correctly entered into the
* integer header (30).

* For flexibility, information is read from a control file.
* Here is an example:
*Control file for program SMCAddSN
*Name of summary file:
* smcaddsn.sum
*Path for input SMC files:
* \psv\pet_ms\usgs\
*Path for output SMC files (can be same as input, then files are overwritten)
* \psv\pet_ms\usgs\
*Name of SMC file:
*319A.SMC
*319B.SMC
*319C.SMC
*334A.SMC
*334B.SMC
*334C.SMC
*stop

*  Dates:  02/05/01 - Written by D. Boore (based on SMCFXHDR.FOR)
*        07/17/03 - Add sps to smc_npts parameter list
*        10/17/07 - Transparent change to user needed because smcread can
*                   read two input formats

      character precision*8


      real  rhead(50)

      integer ihead(48)

      real y(:)
      allocatable :: y

      character chead(11)*80, comments(200)*80, stacode*4
      character path_in*50, path_out*50
      character f_ctl*40, f_in*40, f_out*40, f_smc*40, f_sum*40

      logical f_ctl_exist, nonint_l

* Open Input file:

      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr to quit): '
        read(*, '(a)') f_ctl
        if (f_ctl .eq. ' ') stop
        inquire(file=f_ctl, exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do

      call get_lun(nu_ctl)
      open(unit=nu_ctl, file=f_ctl, status='unknown')

      call skip(nu_ctl,2)
      f_sum = ' '
      read(nu_ctl,'(a)') f_sum
      call get_lun(nu_sum)
      open(unit=nu_sum, file=f_sum, status='unknown')
      write(nu_sum,'(a)') ' Summary from program SMCAddSN'

      call skip(nu_ctl,1)
      path_in = ' '
      read(nu_ctl,'(a)') path_in
      call trim_c(path_in,nc_path_in)

      call skip(nu_ctl,1)
      path_out = ' '
      read(nu_ctl,'(a)') path_out
      call trim_c(path_out,nc_path_out)

      call skip(nu_ctl,1)

1000  continue

      f_smc = ' '
      read(nu_ctl,'(a)') f_smc
      call upstr(f_smc)
      call trim_c(f_smc,nc_f_smc)

      if(f_smc(1:4) .eq. 'STOP') then
        close(nu_ctl)
        close(nu_sum)
        stop
      end if

      f_in = ' '
      f_in = path_in(1:nc_path_in)//f_smc(1:nc_f_smc)
      write(nu_sum,'(2a)') '   f_in = ', f_in(1:nc_path_in+nc_f_smc)

* DEBUG
      write(*,'(2a)') ' f_in = ', f_in
* DEBUG

      call smc_npts(f_in,npts_smc, sps)
      allocate(y(npts_smc))

      tskip = 0.0
      tlength = 9999.9
      call SMCRead(f_in, tskip, tlength,
     :                   y, chead, ihead, rhead, comments)

      precision = ' '
      if (ihead(47) .eq. 8) then
        precision = 'HIGH'
      else
        precision = 'STANDARD'
      end if
      
      stacode = ' '
      stacode = chead(3)(1:4)
      
      call trim_c(stacode,nc_stacode)
      write(nu_sum,'(a,1x,i1,1x,a)') 
     :     '   nc_stacode, stacode = ', nc_stacode, stacode

      if (nc_stacode .gt. 0) then
        call chk4int(stacode, nc_stacode, nonint_l)
        if (nonint_l) then
* go to next file
          write(nu_sum,'(a)') 
     :     '     stacode contains noninteger, going to next file'
          deallocate(y)
          goto 1000
        else
          write(nu_sum,'(a)') 
     :     '     setting ihead(30) to stacode'
          read(stacode,'(i4)') ihead(30)
        end if
      else
* go to next file
        write(nu_sum,'(a)') 
     :     '     nc_stacode = 0.0, going to next file'
        deallocate(y)
        goto 1000
      end if

* Fill comments:

      ncomments = ihead(16)
      comments(ncomments + 1) = '|'
      comments(ncomments + 2) = '|'//
     : ' stanum added to int_head(30) by program SMCAddSN'
      comments(ncomments + 3) = '|'

      ncomments = ncomments + 3
      ihead(16) = ncomments
      itype = -1
      f_out = ' '
      f_out = path_out(1:nc_path_out)//f_smc(1:nc_f_smc)
      write(nu_sum,'(2a)') 
     :     '   f_out = ', f_out(1:nc_path_out+nc_f_smc)

      call SMCWrite(f_out, precision,
     :              y, chead, itype, 
     :                 ihead, rhead, comments)

* That should be it; deallocate the y array and loop back for another file
 
      deallocate(y)

      goto 1000

      end
* ---------------------------------------------------------------- SMCAddSN


      include '\forprogs\skip.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\smcread.for'
      include '\forprogs\smcwrite.for'
      include '\forprogs\upstr.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\mnmax.for'
      include '\forprogs\mnmaxidx.for'
      include '\forprogs\smc_npts.for'
      include '\forprogs\chk4int.for'

                     