
* ---------------------------------------------------------------- SMCFxHdr
       Program SMCFxHdr

*  Adds header information to preexisting SMC files

*  For flexibility, information is read from a control file.
*  Here is an example:
*Control file for program SMCFxHdr
*Name of summary file:
* smcfxhdr.sum
*Quake Params: date, time (iyr, imon, idom, ihrmin), name
* 1999 10 16 0946 HECTOR MINE, CA
*Quake Params: location, magnitude (lat, long, h, Mw, Ms, Ml)
* 34.594 -116.2708 0.0 7.1 7.4 0.0 
*Data Source:
* SCEC
*Comment:
* Files from Linda Seekins; Header info changed by D. Boore
*Path for original SMC files:
* \psv\hector99\scec\seekins
*Name of SMC file:
*ago.u01
*ago.u03
*alp.u01
*alp.u03
*stop

*  Dates:  12/04/00 - Written by D. Boore (based on TAIW2SMC.FOR)
*          12/10/00 - Use dynamically allocatable array for y
*          02/05/01 - Increased dimension of comments to 200
*        07/17/03 - Add sps to smc_npts parameter list
*        10/17/07 - Transparent change to user needed because smcread can
*                   read two input formats

      character precision*8


      real  rhead(50), orient_h, orient_v,  
     :      eqlat, eqlong, rnull

      integer ihead(48), iyr, imon, idom,  ncomments, inull

      real y(:)
      allocatable :: y

      character chead(11)*80, comments(200)*80, eqname*50
      character data_source*45, cmmnt*75, path*50
      character f_ctl*40, f_in*40, f_smc*40, f_sum*40, buf*80

      character staname*4

      logical f_ctl_exist

      inull = -32768
      rnull = +1.7e+38

* Open Input file:

      f_ctl_exist = .false.
      do while (.not. f_ctl_exist)
        f_ctl = ' '
        write(*, '(a\)') 
     :    ' Enter name of control file (cr to quit): '
        read(*, '(a)') f_ctl
        if (f_ctl .eq. ' ') stop
        inquire(file=f_ctl, exist=f_ctl_exist)
        if (.not. f_ctl_exist) then
          write(*,'(a)') ' ******* FILE DOES NOT EXIST ******* '
        end if
      end do

      call get_lun(nu_ctl)
      open(unit=nu_ctl, file=f_ctl, status='unknown')

      call skip(nu_ctl,2)
      f_sum = ' '
      read(nu_ctl,'(a)') f_sum
      call get_lun(nu_sum)
      open(unit=nu_sum, file=f_sum, status='unknown')

      call skip(nu_ctl,1)

      buf = ' '
      read(nu_ctl,'(a)') buf
      call rci(1, buf,80,iyr,ibgn,iend,istat)
      call rci(2, buf,80,imon,ibgn,iend,istat)
      call rci(3, buf,80,idom,ibgn,iend,istat)
      call rci(4, buf,80,ihrmin,ibgn,iend,istat)

      eqname = ' '
      read(buf(iend+1:80),'(a)') eqname
      call trim_c(eqname,nc_eqname)
      write(*,'(2a)') ' eqname = ', eqname(1:nc_eqname)

      call skip(nu_ctl,1)
      buf = ' '
      read(nu_ctl,'(a)') buf
      call rcf(1, buf,80,eqlat,ibgn,iend,istat)
      call rcf(2, buf,80,eqlong,ibgn,iend,istat)
      call rcf(3, buf,80,eqdepth,ibgn,iend,istat)
      call rcf(4, buf,80,eqmw,ibgn,iend,istat)
      call rcf(5, buf,80,eqms,ibgn,iend,istat)
      call rcf(6, buf,80,eqml,ibgn,iend,istat)

      call skip(nu_ctl,1)
      data_source = ' '
      read(nu_ctl,'(a)') data_source
      call trim_c(data_source,nc_ds)

      call skip(nu_ctl,1)
      cmmnt = ' '
      read(nu_ctl,'(a)') cmmnt
      call trim_c(cmmnt,nc_cmmnt)

      call skip(nu_ctl,1)
      path = ' '
      read(nu_ctl,'(a)') path
      call trim_c(path,nc_path)

      call skip(nu_ctl,1)

1000  continue

      f_smc = ' '
      read(nu_ctl,'(a)') f_smc
      call upstr(f_smc)
      call trim_c(f_smc,nc_f_smc)

      if(f_smc(1:4) .eq. 'STOP') then
        close(nu_ctl)
        stop
      end if

      staname = ' '
      staname = f_smc(1:index(f_smc,'.')-1)
      call trim_c(staname,nc_sn)

      f_in = ' '
      f_in = path(1:nc_path)//f_smc(1:nc_f_smc)

* DEBUG
      write(*,'(2a)') ' f_in = ', f_in
* DEBUG

      call smc_npts(f_in,npts_smc, sps)
      allocate(y(npts_smc))

      tskip = 0.0
      tlength = 999.9
      call SMCRead(f_in, tskip, tlength,
     :                   y, chead, ihead, rhead, comments)

      precision = ' '
      if (ihead(47) .eq. 8) then
        precision = 'HIGH'
      else
        precision = 'STANDARD'
      end if
      
      do i = 1, 11
        chead(i) = ' '
      end do

      inull = ihead(1)
      rnull = rhead(1)

      ncomments = ihead(16)
      npts = ihead(17)

      sps = rhead(2)

      stalat = rhead(11)
      stalong = rhead(12)

* Write headers:

* First fill the 11 lines of comments:

      chead(1) = '*'
      chead(2) = '*'

      write(chead(3),'(a)') staname(1:nc_sn)

      write(chead(4),'(5x,i4,2x,i2,2x,i2,4x,i4,1x,a)') 
     :              iyr, imon, idom, ihrmin, eqname(1:nc_eqname)
      chead(5)( 1:11) = 'Moment Mag='
      chead(5)(22:24) = 'MS='
      chead(5)(35:37) = 'ML='
      
      write(chead(5)(13:16),'(f4.2)') eqmw
      write(chead(5)(26:29),'(f4.2)') eqms
      write(chead(5)(39:42),'(f4.2)') eqml

      chead(6)( 1:10) = 'station ='       
      chead(6)(42:51) = 'component='       

      chead(6)(11:40) = staname(1:nc_sn)

      chead(7)( 1:17) = 'epicentral dist ='
*      chead(7)(34:41) = 'pk mtn ='

      if (stalat .ne. rnull .and. stalong .ne. rnull) then
* Compute epicentral distance:
        wlongsign = -1.0
        call distaz( wlongsign, eqlat, eqlong, stalat, stalong,
     :    rdeg, rkm, az, baz)
        write(chead(7)(19:23),'(f5.1)') rkm
      end if

*      call mnmax(y,1,ihead(17),1,ymin,ymax) 
*      pkmtn = ymin
*      if (abs(pkmtn) .lt. abs(ymax)) pkmtn = ymax

*      write(chead(7)(42:50),'(1pe9.2)') pkmtn

      chead(8)( 1:10) = 'inst type='
      chead(8)( 12:15) = 'DGTL'
      chead(8)( 22:33) = 'data source='
      chead(8)( 36:80) = data_source(1:nc_ds)

      chead(9) = '*'
      chead(10) = '*'
      chead(11) = '*'
             
* Now fill the integer header block:

      do i = 1, 48
        ihead(i) = inull
      end do      

      orient_v = 999.
      orient_h = 999.
      ihead(13) = orient_v
      ihead(14) = orient_h
      ihead(17) = npts

* Now fill the real header block:
   
      do i = 1, 50
        rhead(i) = rnull
      end do

      rhead(2) = sps
      rhead(3) = eqlat
      rhead(4) = eqlong
      rhead(5) = eqdepth
      if (eqmw .ne. 0.0) rhead(6) = eqmw
      if (eqms .ne. 0.0) rhead(7) = eqms
      if (eqml .ne. 0.0) rhead(8) = eqml
      rhead(11) = stalat
      rhead(12) = stalong

* Fill comments:

      comments(ncomments + 1) = '|'
      comments(ncomments + 2) = '|'//cmmnt(1:nc_cmmnt)
      comments(ncomments + 3) = '|'

      ncomments = ncomments + 3
      ihead(16) = ncomments
      itype = 1
      call SMCWrite(f_smc, precision,
     :                y, chead, itype, 
     :                 ihead, rhead, comments)

* That should be it; close the output file and loop back for another component
 
      deallocate(y)

      goto 1000
      end
* ---------------------------------------------------------------- SMCFxHdr


      include '\forprogs\rc_subs.for'
      include '\forprogs\skip.for'
      include '\forprogs\doy.for'
      include '\forprogs\get_lun.for'
      include '\forprogs\smcread.for'
      include '\forprogs\smcwrite.for'
      include '\forprogs\upstr.for'
      include '\forprogs\trim_c.for'
      include '\forprogs\mnmax.for'
      include '\forprogs\mnmaxidx.for'
      include '\forprogs\distaz.for'
      include '\forprogs\smc_npts.for'

                     